@@ -7,6 +7,10 @@
         <source>Selected theme is currently in use!</source>
         <translation>选定的主题是目前正在使用!</translation>
     </message>
+    <message>
+        <source>Tune transitions</source>
+        <translation></translation>
+    </message>    
     <message>
         <source>Theme</source>
         <translation type="unfinished"></translation>
